mockconnect

package
v0.4.21 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 31, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AnyRequest

type AnyRequest struct {
	mock.Mock
}

AnyRequest is an autogenerated mock type for the AnyRequest type

func NewAnyRequest

func NewAnyRequest(t interface {
	mock.TestingT
	Cleanup(func())
}) *AnyRequest

NewAnyRequest creates a new instance of AnyRequest. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*AnyRequest) Any

func (_mock *AnyRequest) Any() any

Any provides a mock function for the type AnyRequest

func (*AnyRequest) EXPECT

func (_m *AnyRequest) EXPECT() *AnyRequest_Expecter

func (*AnyRequest) HTTPMethod

func (_mock *AnyRequest) HTTPMethod() string

HTTPMethod provides a mock function for the type AnyRequest

func (*AnyRequest) Header

func (_mock *AnyRequest) Header() http.Header

Header provides a mock function for the type AnyRequest

func (*AnyRequest) Peer

func (_mock *AnyRequest) Peer() connect.Peer

Peer provides a mock function for the type AnyRequest

func (*AnyRequest) Spec

func (_mock *AnyRequest) Spec() connect.Spec

Spec provides a mock function for the type AnyRequest

type AnyRequest_Any_Call

type AnyRequest_Any_Call struct {
	*mock.Call
}

AnyRequest_Any_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Any'

func (*AnyRequest_Any_Call) Return

func (*AnyRequest_Any_Call) Run

func (_c *AnyRequest_Any_Call) Run(run func()) *AnyRequest_Any_Call

func (*AnyRequest_Any_Call) RunAndReturn

func (_c *AnyRequest_Any_Call) RunAndReturn(run func() any) *AnyRequest_Any_Call

type AnyRequest_Expecter

type AnyRequest_Expecter struct {
	// contains filtered or unexported fields
}

func (*AnyRequest_Expecter) Any

Any is a helper method to define mock.On call

func (*AnyRequest_Expecter) HTTPMethod

HTTPMethod is a helper method to define mock.On call

func (*AnyRequest_Expecter) Header

Header is a helper method to define mock.On call

func (*AnyRequest_Expecter) Peer

Peer is a helper method to define mock.On call

func (*AnyRequest_Expecter) Spec

Spec is a helper method to define mock.On call

type AnyRequest_HTTPMethod_Call

type AnyRequest_HTTPMethod_Call struct {
	*mock.Call
}

AnyRequest_HTTPMethod_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'HTTPMethod'

func (*AnyRequest_HTTPMethod_Call) Return

func (*AnyRequest_HTTPMethod_Call) Run

func (*AnyRequest_HTTPMethod_Call) RunAndReturn

func (_c *AnyRequest_HTTPMethod_Call) RunAndReturn(run func() string) *AnyRequest_HTTPMethod_Call

type AnyRequest_Header_Call

type AnyRequest_Header_Call struct {
	*mock.Call
}

AnyRequest_Header_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Header'

func (*AnyRequest_Header_Call) Return

func (*AnyRequest_Header_Call) Run

func (_c *AnyRequest_Header_Call) Run(run func()) *AnyRequest_Header_Call

func (*AnyRequest_Header_Call) RunAndReturn

func (_c *AnyRequest_Header_Call) RunAndReturn(run func() http.Header) *AnyRequest_Header_Call

type AnyRequest_Peer_Call

type AnyRequest_Peer_Call struct {
	*mock.Call
}

AnyRequest_Peer_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Peer'

func (*AnyRequest_Peer_Call) Return

func (*AnyRequest_Peer_Call) Run

func (_c *AnyRequest_Peer_Call) Run(run func()) *AnyRequest_Peer_Call

func (*AnyRequest_Peer_Call) RunAndReturn

func (_c *AnyRequest_Peer_Call) RunAndReturn(run func() connect.Peer) *AnyRequest_Peer_Call

type AnyRequest_Spec_Call

type AnyRequest_Spec_Call struct {
	*mock.Call
}

AnyRequest_Spec_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Spec'

func (*AnyRequest_Spec_Call) Return

func (*AnyRequest_Spec_Call) Run

func (_c *AnyRequest_Spec_Call) Run(run func()) *AnyRequest_Spec_Call

func (*AnyRequest_Spec_Call) RunAndReturn

func (_c *AnyRequest_Spec_Call) RunAndReturn(run func() connect.Spec) *AnyRequest_Spec_Call

type AnyRequest_internalOnly_Call

type AnyRequest_internalOnly_Call struct {
	*mock.Call
}

AnyRequest_internalOnly_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'internalOnly'

func (*AnyRequest_internalOnly_Call) Return

func (*AnyRequest_internalOnly_Call) Run

func (*AnyRequest_internalOnly_Call) RunAndReturn

func (_c *AnyRequest_internalOnly_Call) RunAndReturn(run func()) *AnyRequest_internalOnly_Call

type AnyRequest_setRequestMethod_Call

type AnyRequest_setRequestMethod_Call struct {
	*mock.Call
}

AnyRequest_setRequestMethod_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'setRequestMethod'

func (*AnyRequest_setRequestMethod_Call) Return

func (*AnyRequest_setRequestMethod_Call) Run

func (*AnyRequest_setRequestMethod_Call) RunAndReturn

type StreamingHandlerConn

type StreamingHandlerConn struct {
	mock.Mock
}

StreamingHandlerConn is an autogenerated mock type for the StreamingHandlerConn type

func NewStreamingHandlerConn

func NewStreamingHandlerConn(t interface {
	mock.TestingT
	Cleanup(func())
}) *StreamingHandlerConn

NewStreamingHandlerConn creates a new instance of StreamingHandlerConn. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*StreamingHandlerConn) EXPECT

func (*StreamingHandlerConn) Peer

func (_mock *StreamingHandlerConn) Peer() connect.Peer

Peer provides a mock function for the type StreamingHandlerConn

func (*StreamingHandlerConn) Receive

func (_mock *StreamingHandlerConn) Receive(v any) error

Receive provides a mock function for the type StreamingHandlerConn

func (*StreamingHandlerConn) RequestHeader

func (_mock *StreamingHandlerConn) RequestHeader() http.Header

RequestHeader provides a mock function for the type StreamingHandlerConn

func (*StreamingHandlerConn) ResponseHeader

func (_mock *StreamingHandlerConn) ResponseHeader() http.Header

ResponseHeader provides a mock function for the type StreamingHandlerConn

func (*StreamingHandlerConn) ResponseTrailer

func (_mock *StreamingHandlerConn) ResponseTrailer() http.Header

ResponseTrailer provides a mock function for the type StreamingHandlerConn

func (*StreamingHandlerConn) Send

func (_mock *StreamingHandlerConn) Send(v any) error

Send provides a mock function for the type StreamingHandlerConn

func (*StreamingHandlerConn) Spec

func (_mock *StreamingHandlerConn) Spec() connect.Spec

Spec provides a mock function for the type StreamingHandlerConn

type StreamingHandlerConn_Expecter

type StreamingHandlerConn_Expecter struct {
	// contains filtered or unexported fields
}

func (*StreamingHandlerConn_Expecter) Peer

Peer is a helper method to define mock.On call

func (*StreamingHandlerConn_Expecter) Receive

Receive is a helper method to define mock.On call

  • v any

func (*StreamingHandlerConn_Expecter) RequestHeader

RequestHeader is a helper method to define mock.On call

func (*StreamingHandlerConn_Expecter) ResponseHeader

ResponseHeader is a helper method to define mock.On call

func (*StreamingHandlerConn_Expecter) ResponseTrailer

ResponseTrailer is a helper method to define mock.On call

func (*StreamingHandlerConn_Expecter) Send

Send is a helper method to define mock.On call

  • v any

func (*StreamingHandlerConn_Expecter) Spec

Spec is a helper method to define mock.On call

type StreamingHandlerConn_Peer_Call

type StreamingHandlerConn_Peer_Call struct {
	*mock.Call
}

StreamingHandlerConn_Peer_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Peer'

func (*StreamingHandlerConn_Peer_Call) Return

func (*StreamingHandlerConn_Peer_Call) Run

func (*StreamingHandlerConn_Peer_Call) RunAndReturn

type StreamingHandlerConn_Receive_Call

type StreamingHandlerConn_Receive_Call struct {
	*mock.Call
}

StreamingHandlerConn_Receive_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Receive'

func (*StreamingHandlerConn_Receive_Call) Return

func (*StreamingHandlerConn_Receive_Call) Run

func (*StreamingHandlerConn_Receive_Call) RunAndReturn

type StreamingHandlerConn_RequestHeader_Call

type StreamingHandlerConn_RequestHeader_Call struct {
	*mock.Call
}

StreamingHandlerConn_RequestHeader_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'RequestHeader'

func (*StreamingHandlerConn_RequestHeader_Call) Return

func (*StreamingHandlerConn_RequestHeader_Call) Run

func (*StreamingHandlerConn_RequestHeader_Call) RunAndReturn

type StreamingHandlerConn_ResponseHeader_Call

type StreamingHandlerConn_ResponseHeader_Call struct {
	*mock.Call
}

StreamingHandlerConn_ResponseHeader_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ResponseHeader'

func (*StreamingHandlerConn_ResponseHeader_Call) Return

func (*StreamingHandlerConn_ResponseHeader_Call) Run

func (*StreamingHandlerConn_ResponseHeader_Call) RunAndReturn

type StreamingHandlerConn_ResponseTrailer_Call

type StreamingHandlerConn_ResponseTrailer_Call struct {
	*mock.Call
}

StreamingHandlerConn_ResponseTrailer_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ResponseTrailer'

func (*StreamingHandlerConn_ResponseTrailer_Call) Return

func (*StreamingHandlerConn_ResponseTrailer_Call) Run

func (*StreamingHandlerConn_ResponseTrailer_Call) RunAndReturn

type StreamingHandlerConn_Send_Call

type StreamingHandlerConn_Send_Call struct {
	*mock.Call
}

StreamingHandlerConn_Send_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Send'

func (*StreamingHandlerConn_Send_Call) Return

func (*StreamingHandlerConn_Send_Call) Run

func (*StreamingHandlerConn_Send_Call) RunAndReturn

type StreamingHandlerConn_Spec_Call

type StreamingHandlerConn_Spec_Call struct {
	*mock.Call
}

StreamingHandlerConn_Spec_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Spec'

func (*StreamingHandlerConn_Spec_Call) Return

func (*StreamingHandlerConn_Spec_Call) Run

func (*StreamingHandlerConn_Spec_Call) RunAndReturn

Jump to